@@ -1,15 +1,11 @@
 package QBit::Validator::Type::palindrome;
-$QBit::Validator::Type::palindrome::VERSION = '0.011';
+$QBit::Validator::Type::palindrome::VERSION = '0.012';
 use qbit;
 
 use base qw(QBit::Validator::Type);
 
 use Exception::Validator::FailedField;
 
-sub _get_options {[]}
-
-sub _get_options_name {qw()}
-
 sub get_template {
     return {
         type    => 'scalar',
@@ -17,7 +13,7 @@ sub get_template {
         check   => sub {
             throw FF gettext('String is not a palindrome') unless $_[1] eq reverse($_[1]);
         },
-      };
+    };
 }
 
 TRUE;
